@@ -17,11 +17,16 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.Vm;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.or;
+
 /**
  * This service manages a collection of all the virtual machines assigned to an affinity group.
  *
@@ -56,6 +61,10 @@ public interface AffinityGroupVmsService {
      * @status updated_by_docs
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            or(mandatory(vm().id()), mandatory(vm().name()));
+        }
         @In @Out Vm vm();
     }
 
@@ -69,7 +78,7 @@ public interface AffinityGroupVmsService {
      * @date 31 Jan 2017
      * @status updated_by_docs
      */
-    interface List {
+    interface List extends Follow {
         @Out Vm[] vms();
 
         /**
