@@ -17,11 +17,15 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.IscsiBond;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+
 @Service
 @Area("Storage")
 public interface IscsiBondsService {
@@ -58,6 +62,10 @@ public interface IscsiBondsService {
      * @status added
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(bond().name());
+        }
         @In @Out IscsiBond bond();
     }
 
@@ -70,7 +78,7 @@ public interface IscsiBondsService {
      * @date 15 Apr 2017
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out IscsiBond[] bonds();
 
         /**
