@@ -17,15 +17,31 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.Watchdog;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+
 @Service
 @Area("Virtualization")
 public interface TemplateWatchdogsService {
+    /**
+     * Add a watchdog to the template identified by the given id.
+     *
+     * @author Ori Liel <oliel@redhat.com>
+     * @date 18 Jan 2017
+     * @status added
+     */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(watchdog().action());
+            mandatory(watchdog().model());
+        }
         @In @Out Watchdog watchdog();
     }
 
@@ -38,7 +54,7 @@ public interface TemplateWatchdogsService {
      * @date 15 Apr 2017
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out Watchdog[] watchdogs();
 
         /**
