@@ -17,21 +17,45 @@ limitations under the License.
 package services.openstack;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import services.ExternalProviderService;
 import types.OpenStackImageProvider;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.COLLECTION;
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 @Service
 @Area("Storage")
 public interface OpenstackImageProviderService extends ExternalProviderService {
-    interface Get {
+    interface Get extends Follow {
         @Out
         OpenStackImageProvider provider();
     }
 
+    /**
+     * Update the specified OpenStack image provider in the system.
+     *
+     * @author Ori Liel <oliel@redhat.com>
+     * @date 18 Jan 2017
+     * @status added
+     */
     interface Update {
+        @InputDetail
+        default void inputDetail() {
+            optional(provider().authenticationUrl());
+            optional(provider().description());
+            optional(provider().name());
+            optional(provider().password());
+            optional(provider().requiresAuthentication());
+            optional(provider().tenantName());
+            optional(provider().username());
+            optional(provider().properties()[COLLECTION].name());
+            optional(provider().properties()[COLLECTION].value());
+        }
         @In @Out OpenStackImageProvider provider();
 
         /**
