@@ -115,6 +115,9 @@ public class XmlSnapshotReader {
                 case "disk_attachments":
                 object.diskAttachments(XmlDiskAttachmentReader.readMany(reader));
                 break;
+                case "disks":
+                object.disks(XmlDiskReader.readMany(reader));
+                break;
                 case "display":
                 object.display(XmlDisplayReader.readOne(reader));
                 break;
@@ -417,6 +420,11 @@ public class XmlSnapshotReader {
                 list.href(href);
                 object.diskAttachments(list);
                 break;
+                case "disks":
+                list = new ArrayListWithHref(object.disks());
+                list.href(href);
+                object.disks(list);
+                break;
                 case "floppies":
                 list = new ArrayListWithHref(object.floppies());
                 list.href(href);
