@@ -19,13 +19,15 @@ import java.io.IOException;
 import org.ovirt.engine.sdk4.Request;
 import org.ovirt.engine.sdk4.Response;
 import org.ovirt.engine.sdk4.Service;
-import org.ovirt.engine.sdk4.builders.StatisticBuilder;
 import org.ovirt.engine.sdk4.types.Statistic;
 
 public interface StatisticService extends Service {
     public interface GetRequest extends Request<GetRequest, GetResponse> {
-        GetRequest statistic(Statistic statistic);
-        GetRequest statistic(StatisticBuilder statistic);
+        /**
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        GetRequest follow(String follow);
     }
     
     public interface GetResponse extends Response {
