@@ -19,7 +19,9 @@ import java.lang.Boolean;
 import java.lang.String;
 import java.math.BigInteger;
 import org.ovirt.engine.sdk4.internal.containers.ImageTransferContainer;
+import org.ovirt.engine.sdk4.types.Backup;
 import org.ovirt.engine.sdk4.types.Disk;
+import org.ovirt.engine.sdk4.types.DiskFormat;
 import org.ovirt.engine.sdk4.types.DiskSnapshot;
 import org.ovirt.engine.sdk4.types.Host;
 import org.ovirt.engine.sdk4.types.Image;
@@ -29,14 +31,17 @@ import org.ovirt.engine.sdk4.types.ImageTransferPhase;
 
 public class ImageTransferBuilder {
     private Boolean active;
+    private Backup backup;
     private String comment;
     private String description;
     private ImageTransferDirection direction;
     private Disk disk;
+    private DiskFormat format;
     private Host host;
     private String href;
     private String id;
     private Image image;
+    private BigInteger inactivityTimeout;
     private String name;
     private ImageTransferPhase phase;
     private String proxyUrl;
@@ -56,6 +61,22 @@ public class ImageTransferBuilder {
     }
     
     
+    public ImageTransferBuilder backup(Backup newBackup) {
+        backup = newBackup;
+        return this;
+    }
+    
+    public ImageTransferBuilder backup(BackupBuilder newBackup) {
+        if (newBackup == null) {
+            backup = null;
+        }
+        else {
+            backup = newBackup.build();
+        }
+        return this;
+    }
+    
+    
     public ImageTransferBuilder comment(String newComment) {
         comment = newComment;
         return this;
@@ -90,6 +111,12 @@ public class ImageTransferBuilder {
     }
     
     
+    public ImageTransferBuilder format(DiskFormat newFormat) {
+        format = newFormat;
+        return this;
+    }
+    
+    
     public ImageTransferBuilder host(Host newHost) {
         host = newHost;
         return this;
@@ -134,6 +161,42 @@ public class ImageTransferBuilder {
     }
     
     
+    public ImageTransferBuilder inactivityTimeout(int newInactivityTimeout) {
+        inactivityTimeout = BigInteger.valueOf((long) newInactivityTimeout);
+        return this;
+    }
+    
+    public ImageTransferBuilder inactivityTimeout(Integer newInactivityTimeout) {
+        if (newInactivityTimeout == null) {
+            inactivityTimeout = null;
+        }
+        else {
+            inactivityTimeout = BigInteger.valueOf(newInactivityTimeout.longValue());
+        }
+        return this;
+    }
+    
+    public ImageTransferBuilder inactivityTimeout(long newInactivityTimeout) {
+        inactivityTimeout = BigInteger.valueOf(newInactivityTimeout);
+        return this;
+    }
+    
+    public ImageTransferBuilder inactivityTimeout(Long newInactivityTimeout) {
+        if (newInactivityTimeout == null) {
+            inactivityTimeout = null;
+        }
+        else {
+            inactivityTimeout = BigInteger.valueOf(newInactivityTimeout.longValue());
+        }
+        return this;
+    }
+    
+    public ImageTransferBuilder inactivityTimeout(BigInteger newInactivityTimeout) {
+        inactivityTimeout = newInactivityTimeout;
+        return this;
+    }
+    
+    
     public ImageTransferBuilder name(String newName) {
         name = newName;
         return this;
@@ -219,14 +282,17 @@ public class ImageTransferBuilder {
     public ImageTransfer build() {
         ImageTransferContainer container = new ImageTransferContainer();
         container.active(active);
+        container.backup(backup);
         container.comment(comment);
         container.description(description);
         container.direction(direction);
         container.disk(disk);
+        container.format(format);
         container.host(host);
         container.href(href);
         container.id(id);
         container.image(image);
+        container.inactivityTimeout(inactivityTimeout);
         container.name(name);
         container.phase(phase);
         container.proxyUrl(proxyUrl);
