@@ -50,6 +50,7 @@ import org.ovirt.engine.sdk4.services.GlusterVolumesService;
 import org.ovirt.engine.sdk4.services.NetworkFiltersService;
 import org.ovirt.engine.sdk4.types.Action;
 import org.ovirt.engine.sdk4.types.Cluster;
+import org.ovirt.engine.sdk4.types.ClusterUpgradeAction;
 
 public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
     
@@ -140,6 +141,43 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
         return new GetRequestImpl();
     }
     
+    private class RefreshGlusterHealStatusRequestImpl extends BaseRequest<RefreshGlusterHealStatusRequest, RefreshGlusterHealStatusResponse> implements RefreshGlusterHealStatusRequest {
+        public RefreshGlusterHealStatusResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/refreshglusterhealstatus");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new RefreshGlusterHealStatusResponseImpl();
+        }
+        
+    }
+    
+    private class RefreshGlusterHealStatusResponseImpl implements RefreshGlusterHealStatusResponse {
+    }
+    
+    public RefreshGlusterHealStatusRequest refreshGlusterHealStatus() {
+        return new RefreshGlusterHealStatusRequestImpl();
+    }
+    
     private class RemoveRequestImpl extends BaseRequest<RemoveRequest, RemoveResponse> implements RemoveRequest {
         private Boolean async;
         public RemoveRequest async(Boolean async) {
@@ -377,6 +415,57 @@ public class ClusterServiceImpl extends ServiceImpl implements ClusterService {
         return new UpdateRequestImpl();
     }
     
+    private class UpgradeRequestImpl extends BaseRequest<UpgradeRequest, UpgradeResponse> implements UpgradeRequest {
+        private Boolean async;
+        public UpgradeRequest async(Boolean async) {
+            this.async = async;
+            return this;
+        }
+        
+        private ClusterUpgradeAction upgradeAction;
+        public UpgradeRequest upgradeAction(ClusterUpgradeAction upgradeAction) {
+            this.upgradeAction = upgradeAction;
+            return this;
+        }
+        
+        public UpgradeResponse send() {
+            HttpPost request = new HttpPost(getConnection().getUrl() + getPath() + "/upgrade");
+            try (
+              ByteArrayOutputStream output = new ByteArrayOutputStream();
+              XmlWriter xmlWriter = new XmlWriter(output, true)
+            ) {
+                ActionBuilder action = new ActionBuilder();
+                action.async(async);
+                action.upgradeAction(upgradeAction);
+                XmlActionWriter.writeOne(action.build(), xmlWriter);
+                xmlWriter.flush();
+                request.setEntity(new ByteArrayEntity(output.toByteArray()));
+            }
+            catch (IOException ex) {
+                throw new Error("Failed to write request", ex);
+            }
+            
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
+            HttpResponse response = getConnection().send(request);
+            Action action = checkAction(response);
+            EntityUtils.consumeQuietly(response.getEntity());
+            return new UpgradeResponseImpl();
+        }
+        
+    }
+    
+    private class UpgradeResponseImpl implements UpgradeResponse {
+    }
+    
+    public UpgradeRequest upgrade() {
+        return new UpgradeRequestImpl();
+    }
+    
     public AffinityGroupsService affinityGroupsService() {
         return new AffinityGroupsServiceImpl(getConnection(), getPath() + "/affinitygroups");
     }
