@@ -99,7 +99,9 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlExternalHostProviderReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.provider(XmlExternalHostProviderReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
     private class AddResponseImpl implements AddResponse {
         private ExternalHostProvider provider;
         
-        public AddResponseImpl(ExternalHostProvider provider) {
+        public void provider(ExternalHostProvider provider) {
             this.provider = provider;
         }
         
@@ -156,6 +158,12 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
             return this;
         }
         
+        private String search;
+        public ListRequest search(String search) {
+            this.search = search;
+            return this;
+        }
+        
         public ListResponse send() {
             HttpGet request = null;
             try {
@@ -166,6 +174,9 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
                 if (max != null) {
                     uriBuilder.addParameter("max", XmlWriter.renderInteger(max));
                 }
+                if (search != null) {
+                    uriBuilder.addParameter("search", XmlWriter.renderString(search));
+                }
                 if (query != null) {
                     for (Map.Entry<String, String> queryParam : query.entrySet()) {
                         uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
@@ -190,7 +201,9 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlExternalHostProviderReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.providers(XmlExternalHostProviderReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -201,7 +214,7 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -210,7 +223,7 @@ public class ExternalHostProvidersServiceImpl extends ServiceImpl implements Ext
     private class ListResponseImpl implements ListResponse {
         private List<ExternalHostProvider> providers;
         
-        public ListResponseImpl(List<ExternalHostProvider> providers) {
+        public void providers(List<ExternalHostProvider> providers) {
             this.providers = providers;
         }
         
