@@ -82,7 +82,9 @@ public class VmNumaNodeServiceImpl extends ServiceImpl implements VmNumaNodeServ
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlVirtualNumaNodeReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.node(XmlVirtualNumaNodeReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -93,7 +95,7 @@ public class VmNumaNodeServiceImpl extends ServiceImpl implements VmNumaNodeServ
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -102,7 +104,7 @@ public class VmNumaNodeServiceImpl extends ServiceImpl implements VmNumaNodeServ
     private class GetResponseImpl implements GetResponse {
         private VirtualNumaNode node;
         
-        public GetResponseImpl(VirtualNumaNode node) {
+        public void node(VirtualNumaNode node) {
             this.node = node;
         }
         
@@ -229,7 +231,9 @@ public class VmNumaNodeServiceImpl extends ServiceImpl implements VmNumaNodeServ
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new UpdateResponseImpl(XmlVirtualNumaNodeReader.readOne(reader));
+                    UpdateResponseImpl actionResponse = new UpdateResponseImpl();
+                    actionResponse.node(XmlVirtualNumaNodeReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -240,7 +244,7 @@ public class VmNumaNodeServiceImpl extends ServiceImpl implements VmNumaNodeServ
             }
             else {
                 checkFault(response);
-                return new UpdateResponseImpl(null);
+                return new UpdateResponseImpl();
             }
         }
         
@@ -249,7 +253,7 @@ public class VmNumaNodeServiceImpl extends ServiceImpl implements VmNumaNodeServ
     private class UpdateResponseImpl implements UpdateResponse {
         private VirtualNumaNode node;
         
-        public UpdateResponseImpl(VirtualNumaNode node) {
+        public void node(VirtualNumaNode node) {
             this.node = node;
         }
         
