@@ -46,6 +46,12 @@ public class WeightServiceImpl extends ServiceImpl implements WeightService {
             return this;
         }
         
+        private String follow;
+        public GetRequest follow(String follow) {
+            this.follow = follow;
+            return this;
+        }
+        
         public GetResponse send() {
             HttpGet request = null;
             try {
@@ -53,6 +59,9 @@ public class WeightServiceImpl extends ServiceImpl implements WeightService {
                 if (filter != null) {
                     uriBuilder.addParameter("filter", XmlWriter.renderBoolean(filter));
                 }
+                if (follow != null) {
+                    uriBuilder.addParameter("follow", XmlWriter.renderString(follow));
+                }
                 if (query != null) {
                     for (Map.Entry<String, String> queryParam : query.entrySet()) {
                         uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
@@ -77,7 +86,9 @@ public class WeightServiceImpl extends ServiceImpl implements WeightService {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlWeightReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.weight(XmlWeightReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -88,7 +99,7 @@ public class WeightServiceImpl extends ServiceImpl implements WeightService {
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -97,7 +108,7 @@ public class WeightServiceImpl extends ServiceImpl implements WeightService {
     private class GetResponseImpl implements GetResponse {
         private Weight weight;
         
-        public GetResponseImpl(Weight weight) {
+        public void weight(Weight weight) {
             this.weight = weight;
         }
         
